tiled.media\_type\_registration.SerializationRegistry.media\_types
==================================================================

.. currentmodule:: tiled.media_type_registration

.. automethod:: SerializationRegistry.media_types